diff --git a/crystfel_utils.py b/crystfel_utils.py
index 5825fc176d987fbc9efcb1b7944aaed90bf23266..01aa3b673b830961412bc6744bc311757e117de9 100644
--- a/crystfel_utils.py
+++ b/crystfel_utils.py
@@ -16,8 +16,12 @@
 Utilities for interoperability with data formats used in the CrystFEL
 software package.
 
-This module currently contains a python reimplementation of the
-get_detector_geometry_2 function from CrystFEL.
+Exports:
+
+    Functions:
+
+        load_crystfel_geometry: a python reimplementation of the
+            get_detector_geometry_2 function from CrystFEL.
 """
 
 from __future__ import (absolute_import, division, print_function,
@@ -34,12 +38,12 @@ def _assplode_algebraic(value):
     # libcrystfel/src/detector.c.
     items = [
         item
-        for item in re.split(pattern='([+-])', string=value.strip())
+        for item in re.split('([+-])', string=value.strip())
         if item != ''
     ]
 
     if items and items[0] not in ('+', '-'):
-        items.insert(index=0, object='+')
+        items.insert(0, '+')
 
     return [
         ''.join((items[x], items[x + 1]))
@@ -315,23 +319,29 @@ def _parse_field_bad(key, value, bad):
     return
 
 
-def _check_point(name, panel, fs, ss, min_d, max_d, detector):
+def _check_point(name,
+                 panel,
+                 fs_,
+                 ss_,
+                 min_d,
+                 max_d,
+                 detector):
     # Reimplementation of check_point from
     # libcrystfel/src/detector.c.
-    xs = fs * panel['fsx'] + ss * panel['ssx']
-    ys = fs * panel['fsy'] + ss * panel['ssy']
-    rx = (xs + panel['cnx']) / panel['res']
-    ry = (ys + panel['cny']) / panel['res']
-    dist = math.sqrt(rx * rx + ry * ry)
+    xs_ = fs_ * panel['fsx'] + ss_ * panel['ssx']
+    ys_ = fs_ * panel['fsy'] + ss_ * panel['ssy']
+    rx_ = (xs_ + panel['cnx']) / panel['res']
+    ry_ = (ys_ + panel['cny']) / panel['res']
+    dist = math.sqrt(rx_ * rx_ + ry_ * ry_)
     if dist > max_d:
         detector['furthest_out_panel'] = name
-        detector['furthest_out_fs'] = fs
-        detector['furthest_out_ss'] = ss
+        detector['furthest_out_fs'] = fs_
+        detector['furthest_out_ss'] = ss_
         max_d = dist
     elif dist < min_d:
         detector['furthest_in_panel'] = name
-        detector['furthest_in_fs'] = fs
-        detector['furthest_in_ss'] = ss
+        detector['furthest_in_fs'] = fs_
+        detector['furthest_in_ss'] = ss_
         min_d = dist
 
     return min_d, max_d
@@ -346,8 +356,8 @@ def _find_min_max_d(detector):
         min_d, max_d = _check_point(
             name=name,
             panel=panel,
-            fs=0,
-            ss=0,
+            fs_=0,
+            ss_=0,
             min_d=min_d,
             max_d=max_d,
             detector=detector
@@ -356,8 +366,8 @@ def _find_min_max_d(detector):
         min_d, max_d = _check_point(
             name=name,
             panel=panel,
-            fs=panel['w'],
-            ss=0,
+            fs_=panel['w'],
+            ss_=0,
             min_d=min_d,
             max_d=max_d,
             detector=detector
@@ -366,8 +376,8 @@ def _find_min_max_d(detector):
         min_d, max_d = _check_point(
             name=name,
             panel=panel,
-            fs=0,
-            ss=panel['h'],
+            fs_=0,
+            ss_=panel['h'],
             min_d=min_d,
             max_d=max_d,
             detector=detector
@@ -376,8 +386,8 @@ def _find_min_max_d(detector):
         min_d, max_d = _check_point(
             name=name,
             panel=panel,
-            fs=panel['w'],
-            ss=panel['h'],
+            fs_=panel['w'],
+            ss_=panel['h'],
             min_d=min_d,
             max_d=max_d,
             detector=detector
@@ -406,7 +416,7 @@ def load_crystfel_geometry(filename):
 
     Returns:
 
-        dict: dictionary with the geometry information loaded from the
+        Dict: dictionary with the geometry information loaded from the
         file.
     """
     beam = {
@@ -471,13 +481,13 @@ def load_crystfel_geometry(filename):
         'ss', 'fs'
     ]
 
-    fhandle = open(file=filename, mode='r')
+    fhandle = open(filename, mode='r')
     fhlines = fhandle.readlines()
     for line in fhlines:
         if line.startswith(";"):
             continue
 
-        line_without_comments = line.strip().split(sep=';')[0]
+        line_without_comments = line.strip().split(';')[0]
         line_items = re.split(pattern='([ \t])', string=line_without_comments)
         line_items = [
             item
@@ -714,15 +724,19 @@ def load_crystfel_geometry(filename):
                 )
 
     for panel in detector['panels'].values():
-        d = panel['fsx'] * panel['ssy'] - panel['ssx'] * panel['fsy']
-        if d == 0.0:
+        d__ = panel['fsx'] * panel['ssy'] - panel['ssx'] * panel['fsy']
+        if d__ == 0.0:
             raise RuntimeError("Panel {} transformation is singluar.")
-        panel['xfs'] = panel['ssy'] / d
-        panel['yfs'] = panel['ssx'] / d
-        panel['xss'] = panel['fsy'] / d
-        panel['yss'] = panel['fsx'] / d
+        panel['xfs'] = panel['ssy'] / d__
+        panel['yfs'] = panel['ssx'] / d__
+        panel['xss'] = panel['fsy'] / d__
+        panel['yss'] = panel['fsx'] / d__
 
     _find_min_max_d(detector)
     fhandle.close()
 
+    # The code of this function is synced with the code of the function
+    # 'get_detector_geometry_2' in CrystFEL at commit
+    # 41a8fa9819010fe8ddeb66676fee717f5226c7b8
+
     return detector
diff --git a/doc/build/doctrees/cfelpyutils.crystfel_utils.doctree b/doc/build/doctrees/cfelpyutils.crystfel_utils.doctree
index 880d0b728247eb60ad19b2503cd50f4080d81639..c36f7678188dd6542d29b17f97c286c50685b212 100644
Binary files a/doc/build/doctrees/cfelpyutils.crystfel_utils.doctree and b/doc/build/doctrees/cfelpyutils.crystfel_utils.doctree differ
diff --git a/doc/build/doctrees/cfelpyutils.doctree b/doc/build/doctrees/cfelpyutils.doctree
index 7f6b5f2fa5295917dffb8d46eec3321f1dd5cf80..a2db9d86a967ee3cb935502715293c168b36f211 100644
Binary files a/doc/build/doctrees/cfelpyutils.doctree and b/doc/build/doctrees/cfelpyutils.doctree differ
diff --git a/doc/build/doctrees/cfelpyutils.geometry_utils.doctree b/doc/build/doctrees/cfelpyutils.geometry_utils.doctree
index e9213098cd7c7f54b473dc591f864b15ba5d856d..aa0d5da3c664c8236851b7035a463caa345a6be6 100644
Binary files a/doc/build/doctrees/cfelpyutils.geometry_utils.doctree and b/doc/build/doctrees/cfelpyutils.geometry_utils.doctree differ
diff --git a/doc/build/doctrees/cfelpyutils.parameter_utils.doctree b/doc/build/doctrees/cfelpyutils.parameter_utils.doctree
index af2b18f621844b418c465883b7b1b2e34ffae71b..a4bbfa5261e1eb047718850e434d558e13e4758c 100644
Binary files a/doc/build/doctrees/cfelpyutils.parameter_utils.doctree and b/doc/build/doctrees/cfelpyutils.parameter_utils.doctree differ
diff --git a/doc/build/doctrees/environment.pickle b/doc/build/doctrees/environment.pickle
index 22427ebdc4b23a4c7524305b28ecde4af83d6a14..8b1cfd9f4f81d81939ada6ac269dfe0df75f8646 100644
Binary files a/doc/build/doctrees/environment.pickle and b/doc/build/doctrees/environment.pickle differ
diff --git a/doc/build/doctrees/index.doctree b/doc/build/doctrees/index.doctree
index d56c9586fa0d068f0c18a4f623500e634cd03cca..f5d0ebcaece3d183b097316574c19a550ef50061 100644
Binary files a/doc/build/doctrees/index.doctree and b/doc/build/doctrees/index.doctree differ
diff --git a/doc/build/doctrees/modules.doctree b/doc/build/doctrees/modules.doctree
index 28d0cc033db2087350b9542db40f668f3063e9c5..80d31ec402191e61cafbd19f4dcc0483376048ab 100644
Binary files a/doc/build/doctrees/modules.doctree and b/doc/build/doctrees/modules.doctree differ
diff --git a/doc/build/html/.buildinfo b/doc/build/html/.buildinfo
index ff6c4f2a6a3e7d06d6ba52ede8bd4a924317c8b8..84b02eea3e92d6a5529f100db832a597fc40a725 100644
--- a/doc/build/html/.buildinfo
+++ b/doc/build/html/.buildinfo
@@ -1,4 +1,4 @@
 # Sphinx build info version 1
 # This file hashes the configuration used when building these files. When it is not found, a full rebuild will be done.
-config: d40e958a7d3fc689b5ae78674cab31f2
+config: b3b7939111dbbf905db0123cb645320e
 tags: 645f666f9bcd5a90fca523b33c5a78b7
diff --git a/doc/build/html/_static/basic.css b/doc/build/html/_static/basic.css
index dc88b5a2d0086b2364d6626b16700bbb0f82821e..6f408303f8353eac5731eef280694f62a5a4f479 100644
--- a/doc/build/html/_static/basic.css
+++ b/doc/build/html/_static/basic.css
@@ -4,7 +4,7 @@
  *
  * Sphinx stylesheet -- basic theme.
  *
- * :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+ * :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
  * :license: BSD, see LICENSE for details.
  *
  */
@@ -398,6 +398,13 @@ table.field-list td, table.field-list th {
     margin: 0;
 }
 
+.field-name {
+    -moz-hyphens: manual;
+    -ms-hyphens: manual;
+    -webkit-hyphens: manual;
+    hyphens: manual;
+}
+
 /* -- other body styles ----------------------------------------------------- */
 
 ol.arabic {
@@ -438,10 +445,14 @@ dd {
     margin-left: 30px;
 }
 
-dt:target, .highlighted {
+dt:target, span.highlighted {
     background-color: #fbe54e;
 }
 
+rect.highlighted {
+    fill: #fbe54e;
+}
+
 dl.glossary dt {
     font-weight: bold;
     font-size: 1.1em;
diff --git a/doc/build/html/_static/doctools.js b/doc/build/html/_static/doctools.js
index 56549772348502981be27d8a3196baf789b40794..0c15c0099b5df57d89479a679ae7b060d514e8e2 100644
--- a/doc/build/html/_static/doctools.js
+++ b/doc/build/html/_static/doctools.js
@@ -4,7 +4,7 @@
  *
  * Sphinx JavaScript utilities for all documentation.
  *
- * :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+ * :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
  * :license: BSD, see LICENSE for details.
  *
  */
@@ -45,7 +45,7 @@ jQuery.urlencode = encodeURIComponent;
  * it will always return arrays of strings for the value parts.
  */
 jQuery.getQueryParameters = function(s) {
-  if (typeof s == 'undefined')
+  if (typeof s === 'undefined')
     s = document.location.search;
   var parts = s.substr(s.indexOf('?') + 1).split('&');
   var result = {};
@@ -66,29 +66,53 @@ jQuery.getQueryParameters = function(s) {
  * span elements with the given class name.
  */
 jQuery.fn.highlightText = function(text, className) {
-  function highlight(node) {
-    if (node.nodeType == 3) {
+  function highlight(node, addItems) {
+    if (node.nodeType === 3) {
       var val = node.nodeValue;
       var pos = val.toLowerCase().indexOf(text);
       if (pos >= 0 && !jQuery(node.parentNode).hasClass(className)) {
-        var span = document.createElement("span");
-        span.className = className;
+        var span;
+        var isInSVG = jQuery(node).closest("body, svg, foreignObject").is("svg");
+        if (isInSVG) {
+          span = document.createElementNS("http://www.w3.org/2000/svg", "tspan");
+        } else {
+          span = document.createElement("span");
+          span.className = className;
+        }
         span.appendChild(document.createTextNode(val.substr(pos, text.length)));
         node.parentNode.insertBefore(span, node.parentNode.insertBefore(
           document.createTextNode(val.substr(pos + text.length)),
           node.nextSibling));
         node.nodeValue = val.substr(0, pos);
+        if (isInSVG) {
+          var bbox = span.getBBox();
+          var rect = document.createElementNS("http://www.w3.org/2000/svg", "rect");
+       	  rect.x.baseVal.value = bbox.x;
+          rect.y.baseVal.value = bbox.y;
+          rect.width.baseVal.value = bbox.width;
+          rect.height.baseVal.value = bbox.height;
+          rect.setAttribute('class', className);
+          var parentOfText = node.parentNode.parentNode;
+          addItems.push({
+              "parent": node.parentNode,
+              "target": rect});
+        }
       }
     }
     else if (!jQuery(node).is("button, select, textarea")) {
       jQuery.each(node.childNodes, function() {
-        highlight(this);
+        highlight(this, addItems);
       });
     }
   }
-  return this.each(function() {
-    highlight(this);
+  var addItems = [];
+  var result = this.each(function() {
+    highlight(this, addItems);
   });
+  for (var i = 0; i < addItems.length; ++i) {
+    jQuery(addItems[i].parent).before(addItems[i].target);
+  }
+  return result;
 };
 
 /*
@@ -131,21 +155,21 @@ var Documentation = {
    * i18n support
    */
   TRANSLATIONS : {},
-  PLURAL_EXPR : function(n) { return n == 1 ? 0 : 1; },
+  PLURAL_EXPR : function(n) { return n === 1 ? 0 : 1; },
   LOCALE : 'unknown',
 
   // gettext and ngettext don't access this so that the functions
   // can safely bound to a different name (_ = Documentation.gettext)
   gettext : function(string) {
     var translated = Documentation.TRANSLATIONS[string];
-    if (typeof translated == 'undefined')
+    if (typeof translated === 'undefined')
       return string;
-    return (typeof translated == 'string') ? translated : translated[0];
+    return (typeof translated === 'string') ? translated : translated[0];
   },
 
   ngettext : function(singular, plural, n) {
     var translated = Documentation.TRANSLATIONS[singular];
-    if (typeof translated == 'undefined')
+    if (typeof translated === 'undefined')
       return (n == 1) ? singular : plural;
     return translated[Documentation.PLURALEXPR(n)];
   },
@@ -180,7 +204,7 @@ var Documentation = {
    * see: https://bugzilla.mozilla.org/show_bug.cgi?id=645075
    */
   fixFirefoxAnchorBug : function() {
-    if (document.location.hash)
+    if (document.location.hash && $.browser.mozilla)
       window.setTimeout(function() {
         document.location.href += '';
       }, 10);
@@ -216,7 +240,7 @@ var Documentation = {
       var src = $(this).attr('src');
       var idnum = $(this).attr('id').substr(7);
       $('tr.cg-' + idnum).toggle();
-      if (src.substr(-9) == 'minus.png')
+      if (src.substr(-9) === 'minus.png')
         $(this).attr('src', src.substr(0, src.length-9) + 'plus.png');
       else
         $(this).attr('src', src.substr(0, src.length-8) + 'minus.png');
@@ -248,7 +272,7 @@ var Documentation = {
     var path = document.location.pathname;
     var parts = path.split(/\//);
     $.each(DOCUMENTATION_OPTIONS.URL_ROOT.split(/\//), function() {
-      if (this == '..')
+      if (this === '..')
         parts.pop();
     });
     var url = parts.join('/');
diff --git a/doc/build/html/_static/searchtools.js b/doc/build/html/_static/searchtools.js
index c82157380b008f641a14e50619a23cc5c0b4b04d..41b8336776442fbc64332ffbd3d2c1ddd8b3b9c2 100644
--- a/doc/build/html/_static/searchtools.js
+++ b/doc/build/html/_static/searchtools.js
@@ -4,7 +4,7 @@
  *
  * Sphinx JavaScript utilities for the full-text search.
  *
- * :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+ * :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
  * :license: BSD, see LICENSE for details.
  *
  */
@@ -540,6 +540,9 @@ var Search = {
           });
         } else if (DOCUMENTATION_OPTIONS.HAS_SOURCE) {
           var suffix = DOCUMENTATION_OPTIONS.SOURCELINK_SUFFIX;
+          if (suffix === undefined) {
+            suffix = '.txt';
+          }
           $.ajax({url: DOCUMENTATION_OPTIONS.URL_ROOT + '_sources/' + item[5] + (item[5].slice(-suffix.length) === suffix ? '' : suffix),
                   dataType: "text",
                   complete: function(jqxhr, textstatus) {
diff --git a/doc/build/html/_static/sphinxdoc.css b/doc/build/html/_static/sphinxdoc.css
index 88767732383d7770e53ed547acac0dcb32257681..3d94896846bd7e0e13abe04390ed17232c687de7 100644
--- a/doc/build/html/_static/sphinxdoc.css
+++ b/doc/build/html/_static/sphinxdoc.css
@@ -5,7 +5,7 @@
  * Sphinx stylesheet -- sphinxdoc theme.  Originally created by
  * Armin Ronacher for Werkzeug.
  *
- * :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+ * :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
  * :license: BSD, see LICENSE for details.
  *
  */
diff --git a/doc/build/html/_static/websupport.js b/doc/build/html/_static/websupport.js
index 53f6a4525cd3db79b5076e557b0d4c89d810fcae..79b18e3898556c26eeebd259cb91868b8b6200c8 100644
--- a/doc/build/html/_static/websupport.js
+++ b/doc/build/html/_static/websupport.js
@@ -4,7 +4,7 @@
  *
  * sphinx.websupport utilities for all documentation.
  *
- * :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+ * :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
  * :license: BSD, see LICENSE for details.
  *
  */
diff --git a/doc/build/html/cfelpyutils.crystfel_utils.html b/doc/build/html/cfelpyutils.crystfel_utils.html
index fb516cdbef717a87d93a1f0ec3e5904a0c79c361..492008d02e2e21df98621321bf44c43834e9d43d 100644
--- a/doc/build/html/cfelpyutils.crystfel_utils.html
+++ b/doc/build/html/cfelpyutils.crystfel_utils.html
@@ -1,16 +1,13 @@
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>cfelpyutils.crystfel_utils module &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -27,7 +24,7 @@
     <link rel="index" title="Index" href="genindex.html" />
     <link rel="search" title="Search" href="search.html" /> 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -71,8 +68,16 @@
 <span id="cfelpyutils-crystfel-utils-module"></span><h1>cfelpyutils.crystfel_utils module<a class="headerlink" href="#module-cfelpyutils.crystfel_utils" title="Permalink to this headline">¶</a></h1>
 <p>Utilities for interoperability with data formats used in the CrystFEL
 software package.</p>
-<p>This module currently contains a python reimplementation of the
-get_detector_geometry_2 function from CrystFEL.</p>
+<p>Exports:</p>
+<blockquote>
+<div><p>Functions:</p>
+<blockquote>
+<div><dl class="docutils">
+<dt>load_crystfel_geometry: a python reimplementation of the</dt>
+<dd>get_detector_geometry_2 function from CrystFEL.</dd>
+</dl>
+</div></blockquote>
+</div></blockquote>
 <dl class="function">
 <dt id="cfelpyutils.crystfel_utils.load_crystfel_geometry">
 <code class="descclassname">cfelpyutils.crystfel_utils.</code><code class="descname">load_crystfel_geometry</code><span class="sig-paren">(</span><em>filename</em><span class="sig-paren">)</span><a class="headerlink" href="#cfelpyutils.crystfel_utils.load_crystfel_geometry" title="Permalink to this definition">¶</a></dt>
@@ -84,18 +89,18 @@ file to keys in the returned dictionary. For a full documentation
 on the CrystFEL geometry format, see:</p>
 <p><a class="reference external" href="http://www.desy.de/~twhite/crystfel/manual-crystfel_geometry.html">http://www.desy.de/~twhite/crystfel/manual-crystfel_geometry.html</a></p>
 <p>The code of this function is synced with the code of the function
-&#8216;get_detector_geometry_2&#8217; in CrystFEL at commit
+‘get_detector_geometry_2’ in CrystFEL at commit
 41a8fa9819010fe8ddeb66676fee717f5226c7b8.</p>
 <table class="docutils field-list" frame="void" rules="none">
 <col class="field-name" />
 <col class="field-body" />
 <tbody valign="top">
-<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><strong>filename</strong> (<em>str</em>) &#8211; filename of the geometry file.</td>
+<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><strong>filename</strong> (<em>str</em>) – filename of the geometry file.</td>
 </tr>
 <tr class="field-even field"><th class="field-name">Returns:</th><td class="field-body">dictionary with the geometry information loaded from the
 file.</td>
 </tr>
-<tr class="field-odd field"><th class="field-name">Return type:</th><td class="field-body">dict</td>
+<tr class="field-odd field"><th class="field-name">Return type:</th><td class="field-body">Dict</td>
 </tr>
 </tbody>
 </table>
@@ -123,7 +128,7 @@ file.</td>
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/cfelpyutils.geometry_utils.html b/doc/build/html/cfelpyutils.geometry_utils.html
index d95cf85a80fd43ac7cac63f2da6dc78ea64f0b2e..02ca82b2ba0a973f9b91bc114c62f1a0c0074d81 100644
--- a/doc/build/html/cfelpyutils.geometry_utils.html
+++ b/doc/build/html/cfelpyutils.geometry_utils.html
@@ -1,16 +1,13 @@
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>cfelpyutils.geometry_utils module &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -27,7 +24,7 @@
     <link rel="index" title="Index" href="genindex.html" />
     <link rel="search" title="Search" href="search.html" /> 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -69,9 +66,55 @@
             
   <div class="section" id="module-cfelpyutils.geometry_utils">
 <span id="cfelpyutils-geometry-utils-module"></span><h1>cfelpyutils.geometry_utils module<a class="headerlink" href="#module-cfelpyutils.geometry_utils" title="Permalink to this headline">¶</a></h1>
-<p>Geometry utilities.</p>
-<p>Functions that load, manipulate and apply geometry information to
+<p>Utilities to load, manipulate and apply geometry information to
 detector pixel data.</p>
+<p>Exports:</p>
+<blockquote>
+<div><p>Functions:</p>
+<blockquote>
+<div><dl class="docutils">
+<dt>compute_pixel_maps: turn a CrystFEL geometry object into pixel</dt>
+<dd>maps.</dd>
+<dt>apply_pixel_maps: apply pixel maps to a data array. Return an</dt>
+<dd>array containing data with the geometry applied.</dd>
+<dt>compute_minimum_array_size: compute the minimum array size that</dt>
+<dd>is required to store data to which a geometry has been
+applied.</dd>
+<dt>adjust_pixel_maps_for_pyqtgraph: ajust pixel maps to be used in</dt>
+<dd>a PyQtGraph’s ImageView widget.</dd>
+</dl>
+</div></blockquote>
+</div></blockquote>
+<dl class="class">
+<dt id="cfelpyutils.geometry_utils.PixelMaps">
+<em class="property">class </em><code class="descclassname">cfelpyutils.geometry_utils.</code><code class="descname">PixelMaps</code><span class="sig-paren">(</span><em>x</em>, <em>y</em>, <em>r</em><span class="sig-paren">)</span><a class="headerlink" href="#cfelpyutils.geometry_utils.PixelMaps" title="Permalink to this definition">¶</a></dt>
+<dd><p>Bases: <code class="xref py py-class docutils literal"><span class="pre">tuple</span></code></p>
+<p>Pixel maps storing data geometry.</p>
+<p>A namedtuple that stores the pixel maps describing the geometry of a
+dataset. The first two fields, named “x” and “y” respectively, store
+the pixel maps for the x coordinate and the y coordinate. The third
+field, named “r”, is instead a pixel map storing the distance of each
+pixel in the data array from the center of the reference system.</p>
+<dl class="attribute">
+<dt id="cfelpyutils.geometry_utils.PixelMaps.r">
+<code class="descname">r</code><a class="headerlink" href="#cfelpyutils.geometry_utils.PixelMaps.r" title="Permalink to this definition">¶</a></dt>
+<dd><p>Alias for field number 2</p>
+</dd></dl>
+
+<dl class="attribute">
+<dt id="cfelpyutils.geometry_utils.PixelMaps.x">
+<code class="descname">x</code><a class="headerlink" href="#cfelpyutils.geometry_utils.PixelMaps.x" title="Permalink to this definition">¶</a></dt>
+<dd><p>Alias for field number 0</p>
+</dd></dl>
+
+<dl class="attribute">
+<dt id="cfelpyutils.geometry_utils.PixelMaps.y">
+<code class="descname">y</code><a class="headerlink" href="#cfelpyutils.geometry_utils.PixelMaps.y" title="Permalink to this definition">¶</a></dt>
+<dd><p>Alias for field number 1</p>
+</dd></dl>
+
+</dd></dl>
+
 <dl class="function">
 <dt id="cfelpyutils.geometry_utils.adjust_pixel_maps_for_pyqtgraph">
 <code class="descclassname">cfelpyutils.geometry_utils.</code><code class="descname">adjust_pixel_maps_for_pyqtgraph</code><span class="sig-paren">(</span><em>pixel_maps</em><span class="sig-paren">)</span><a class="headerlink" href="#cfelpyutils.geometry_utils.adjust_pixel_maps_for_pyqtgraph" title="Permalink to this definition">¶</a></dt>
@@ -82,27 +125,18 @@ widget.</p>
 <col class="field-name" />
 <col class="field-body" />
 <tbody valign="top">
-<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><ul class="first simple">
-<li><strong>ndarray</strong><strong>, </strong><strong>ndarray</strong><strong>]</strong> (<em>Tuple</em><em>[</em><em>ndarray</em><em>,</em>) &#8211; a named tuple containing the</li>
-<li><strong>maps. The first two fields</strong><strong>, </strong><strong>&quot;x&quot; and &quot;y&quot;</strong><strong>, </strong><strong>should store the</strong> (<em>pixel</em>) &#8211; </li>
-<li><strong>maps for the x coordinateand the y coordinate. The third</strong><strong>,</strong> (<em>pixel</em>) &#8211; </li>
-<li><strong>should instead store the distance of each pixel in the</strong> (<em>&quot;r&quot;</em><em>,</em>) &#8211; </li>
-<li><strong>array from the center of the reference system.</strong> (<em>data</em>) &#8211; </li>
-</ul>
-</td>
+<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><strong>pixel_maps</strong> (<a class="reference internal" href="#cfelpyutils.geometry_utils.PixelMaps" title="cfelpyutils.geometry_utils.PixelMaps"><em>PixelMaps</em></a>) – a PixelMaps tuple.</td>
 </tr>
-<tr class="field-even field"><th class="field-name">Returns:</th><td class="field-body"><p class="first last"><dl class="docutils">
-<dt>Tuple[ndarray, ndarray] A tuple containing the pixel</dt>
-<dd><p class="first last">maps. The first two fields, named &#8220;x&#8221; and &#8220;y&#8221; respectively,
+<tr class="field-even field"><th class="field-name">Returns:</th><td class="field-body"><dl class="docutils">
+<dt>A Pixelmaps tuple containing the adjusted pixel</dt>
+<dd>maps. The first two fields, named “x” and “y” respectively,
 store the pixel maps for the x coordinate and the y
-coordinate. The third field, named &#8220;r&#8221;, is instead a pixel
-map storing the distance of each pixel in the data array
-from the center of the reference system.</p>
-</dd>
+coordinate. The third field (“r”) is just set to None.</dd>
 </dl>
-</p>
 </td>
 </tr>
+<tr class="field-odd field"><th class="field-name">Return type:</th><td class="field-body"><a class="reference internal" href="#cfelpyutils.geometry_utils.PixelMaps" title="cfelpyutils.geometry_utils.PixelMaps">PixelMaps</a></td>
+</tr>
 </tbody>
 </table>
 </dd></dl>
@@ -110,19 +144,19 @@ from the center of the reference system.</p>
 <dl class="function">
 <dt id="cfelpyutils.geometry_utils.apply_pixel_maps">
 <code class="descclassname">cfelpyutils.geometry_utils.</code><code class="descname">apply_pixel_maps</code><span class="sig-paren">(</span><em>data</em>, <em>pixel_maps</em>, <em>output_array=None</em><span class="sig-paren">)</span><a class="headerlink" href="#cfelpyutils.geometry_utils.apply_pixel_maps" title="Permalink to this definition">¶</a></dt>
-<dd><p>Apply geometry in pixel map format to the input data.</p>
-<p>Turn an array of detector pixel values into an array
+<dd><p>Apply geometry to the input data.</p>
+<p>Apply the geometry (in pixel maps format) to the data. In other
+words, turn an array of detector pixel values into an array
 containing a representation of the physical layout of the detector.</p>
 <table class="docutils field-list" frame="void" rules="none">
 <col class="field-name" />
 <col class="field-body" />
 <tbody valign="top">
 <tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><ul class="first simple">
-<li><strong>data</strong> (<em>ndarray</em>) &#8211; array containing the data on which the geometry
+<li><strong>data</strong> (<em>ndarray</em>) – array containing the data on which the geometry
 will be applied.</li>
-<li><strong>pixel_maps</strong> (<em>PixelMaps</em>) &#8211; a pixelmap tuple, as returned by the
-<a class="reference internal" href="#cfelpyutils.geometry_utils.compute_pixel_maps" title="cfelpyutils.geometry_utils.compute_pixel_maps"><code class="xref py py-obj docutils literal"><span class="pre">compute_pixel_maps</span></code></a> function in this module.</li>
-<li><strong>output_array</strong> (<em>Optional</em><em>[</em><em>ndarray</em><em>]</em>) &#8211; a preallocated array (of
+<li><strong>pixel_maps</strong> (<a class="reference internal" href="#cfelpyutils.geometry_utils.PixelMaps" title="cfelpyutils.geometry_utils.PixelMaps"><em>PixelMaps</em></a>) – a PixelMaps tuple.</li>
+<li><strong>output_array</strong> (<em>Optional</em><em>[</em><em>ndarray</em><em>]</em>) – a preallocated array (of
 dtype numpy.float32) to store the function output. If
 provided, this array will be filled by the function and
 and returned to the user. If not provided, the function
@@ -131,9 +165,9 @@ user. Defaults to None (No array provided).</li>
 </ul>
 </td>
 </tr>
-<tr class="field-even field"><th class="field-name">Returns:</th><td class="field-body"><p class="first">a numpy.float32 array containing the geometry
-information applied to the input data (i.e.: a representation
-of the physical layout of the detector).</p>
+<tr class="field-even field"><th class="field-name">Returns:</th><td class="field-body"><p class="first">a numpy.float32 array containing the data with the
+geometry applied (i.e.: a representation of the physical layout
+of the detector).</p>
 </td>
 </tr>
 <tr class="field-odd field"><th class="field-name">Return type:</th><td class="field-body"><p class="first last">ndarray</p>
@@ -146,25 +180,19 @@ of the physical layout of the detector).</p>
 <dl class="function">
 <dt id="cfelpyutils.geometry_utils.compute_minimum_array_size">
 <code class="descclassname">cfelpyutils.geometry_utils.</code><code class="descname">compute_minimum_array_size</code><span class="sig-paren">(</span><em>pixel_maps</em><span class="sig-paren">)</span><a class="headerlink" href="#cfelpyutils.geometry_utils.compute_minimum_array_size" title="Permalink to this definition">¶</a></dt>
-<dd><p>Compute the minimum size of an array that can store the applied
-geometry.</p>
+<dd><p>Compute the minimum array size storing data with applied geometry.</p>
 <p>Return the minimum size of an array that can store data on which
 the geometry information described by the pixel maps has been
 applied.</p>
 <p>The returned array shape is big enough to display all the input
 pixel values in the reference system of the physical detector. The
-array is supposed to be centered at the center of the reference
-system of the detector (i.e: the beam interaction point).</p>
+array is also supposed to be centered at the center of the
+reference system of the detector (i.e: the beam interaction point).</p>
 <table class="docutils field-list" frame="void" rules="none">
 <col class="field-name" />
 <col class="field-body" />
 <tbody valign="top">
-<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><strong>ndarray</strong><strong>, </strong><strong>ndarray</strong><strong>]</strong> (<em>Tuple</em><em>[</em><em>ndarray</em><em>,</em>) &#8211; a named tuple containing the
-pixel maps. The first two fields, &#8220;x&#8221; and &#8220;y&#8221;, should store
-the pixel maps for the x coordinateand the y coordinate.
-The third, &#8220;r&#8221;, should instead store the distance of each
-pixel in the data array from the center of the reference
-system.</td>
+<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><strong>[</strong><strong>PixelMaps</strong><strong>]</strong> (<em>pixel_maps</em>) – a PixelMaps tuple.</td>
 </tr>
 <tr class="field-even field"><th class="field-name">Returns:</th><td class="field-body">a numpy-style shape tuple storing the minimum
 array size.</td>
@@ -188,17 +216,14 @@ interaction point.</p>
 <col class="field-name" />
 <col class="field-body" />
 <tbody valign="top">
-<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><strong>geometry</strong> (<em>dict</em>) &#8211; A CrystFEL geometry object (A dictionary
+<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><strong>geometry</strong> (<em>dict</em>) – A CrystFEL geometry object (A dictionary
 returned by the
 <a class="reference internal" href="cfelpyutils.crystfel_utils.html#cfelpyutils.crystfel_utils.load_crystfel_geometry" title="cfelpyutils.crystfel_utils.load_crystfel_geometry"><code class="xref py py-obj docutils literal"><span class="pre">cfelpyutils.crystfel_utils.load_crystfel_geometry</span></code></a>
 function).</td>
 </tr>
-<tr class="field-even field"><th class="field-name">Returns:</th><td class="field-body">Tuple[ndarray, ndarray, ndarray] A tuple containing the pixel
-maps. The first two fields, named &#8220;x&#8221; and &#8220;y&#8221; respectively,
-store the pixel maps for the x coordinate and the y coordinate.
-The third field, named &#8220;r&#8221;, is instead a pixel map storing the
-distance of each pixel in the data array from the center of the
-reference system.</td>
+<tr class="field-even field"><th class="field-name">Returns:</th><td class="field-body">A PixelMaps tuple.</td>
+</tr>
+<tr class="field-odd field"><th class="field-name">Return type:</th><td class="field-body"><a class="reference internal" href="#cfelpyutils.geometry_utils.PixelMaps" title="cfelpyutils.geometry_utils.PixelMaps">PixelMaps</a></td>
 </tr>
 </tbody>
 </table>
@@ -226,7 +251,7 @@ reference system.</td>
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/cfelpyutils.html b/doc/build/html/cfelpyutils.html
index bb9c7a185017dccdca214a727475b03732791a08..b15f0c977208848f95dfd285d6a0c20b50dd323a 100644
--- a/doc/build/html/cfelpyutils.html
+++ b/doc/build/html/cfelpyutils.html
@@ -1,16 +1,13 @@
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>cfelpyutils package &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -27,7 +24,7 @@
     <link rel="index" title="Index" href="genindex.html" />
     <link rel="search" title="Search" href="search.html" /> 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -122,7 +119,7 @@ python to work with several file format used in x-ray imaging).</p>
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/cfelpyutils.parameter_utils.html b/doc/build/html/cfelpyutils.parameter_utils.html
index b67466866088ddd46d3578c34609e19b44597449..aa19b1b698592404368136741ccb54e33151113b 100644
--- a/doc/build/html/cfelpyutils.parameter_utils.html
+++ b/doc/build/html/cfelpyutils.parameter_utils.html
@@ -1,16 +1,13 @@
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>cfelpyutils.parameter_utils module &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -27,7 +24,7 @@
     <link rel="index" title="Index" href="genindex.html" />
     <link rel="search" title="Search" href="search.html" /> 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -70,13 +67,24 @@
   <div class="section" id="module-cfelpyutils.parameter_utils">
 <span id="cfelpyutils-parameter-utils-module"></span><h1>cfelpyutils.parameter_utils module<a class="headerlink" href="#module-cfelpyutils.parameter_utils" title="Permalink to this headline">¶</a></h1>
 <p>Utilities for parsing command line options and configuration files.</p>
+<p>Exports:</p>
+<blockquote>
+<div><p>Functions:</p>
+<blockquote>
+<div><dl class="docutils">
+<dt>convert_parameters: convert a dictionary returned by the</dt>
+<dd>configparse module to a dictionary containing entries with
+the correct type.</dd>
+</dl>
+</div></blockquote>
+</div></blockquote>
 <dl class="function">
 <dt id="cfelpyutils.parameter_utils.convert_parameters">
 <code class="descclassname">cfelpyutils.parameter_utils.</code><code class="descname">convert_parameters</code><span class="sig-paren">(</span><em>config_dict</em><span class="sig-paren">)</span><a class="headerlink" href="#cfelpyutils.parameter_utils.convert_parameters" title="Permalink to this definition">¶</a></dt>
-<dd><p>Convert strings in parameter dictionaries to the corrent data type.</p>
-<p>Read a parameter dictionary returned by the ConfigParser python
-module, and convert each entry in an object of the corresponding
-type, without changing the structure of the dictionary.</p>
+<dd><p>Convert strings in parameter dictionaries to the correct data type.</p>
+<p>Convert a dictionary return by the configparse module to a
+dictionar contaning the same parameters converted from string to
+their correct type (int, float, string, etc.)</p>
 <p>Try to convert each entry in the dictionary according to the
 following rules. The first rule that applies to the entry
 determines the type.</p>
@@ -116,7 +124,7 @@ try to interpret the entry in order as:</p>
 <col class="field-name" />
 <col class="field-body" />
 <tbody valign="top">
-<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><p class="first"><strong>config</strong> (<em>dict</em>) &#8211; a dictionary containing strings (the dictionary
+<tr class="field-odd field"><th class="field-name">Parameters:</th><td class="field-body"><p class="first"><strong>config</strong> (<em>Dict</em>) – a dictionary containing strings (the dictionary
 returned by Config Parser).</p>
 </td>
 </tr>
@@ -124,11 +132,11 @@ returned by Config Parser).</p>
 dictionary, but with correct types assigned to each entry.</p>
 </td>
 </tr>
-<tr class="field-odd field"><th class="field-name">Return type:</th><td class="field-body"><p class="first">dict</p>
+<tr class="field-odd field"><th class="field-name">Return type:</th><td class="field-body"><p class="first">Dict</p>
 </td>
 </tr>
 <tr class="field-even field"><th class="field-name">Raises:</th><td class="field-body"><ul class="first last simple">
-<li><code class="xref py py-exc docutils literal"><span class="pre">RuntimeError</span></code> &#8211; if an entry cannot be converted to any supported</li>
+<li><code class="xref py py-exc docutils literal"><span class="pre">RuntimeError</span></code> – if an entry cannot be converted to any supported</li>
 <li><code class="xref py py-exc docutils literal"><span class="pre">type.</span></code></li>
 </ul>
 </td>
@@ -159,7 +167,7 @@ dictionary, but with correct types assigned to each entry.</p>
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/genindex.html b/doc/build/html/genindex.html
index 8e3eaeb99a43e027e5dcb15320d9faa2484a06df..7fee42b0b8307457b08b4354b9e439866df2d0df 100644
--- a/doc/build/html/genindex.html
+++ b/doc/build/html/genindex.html
@@ -1,17 +1,14 @@
 
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>Index &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -28,7 +25,7 @@
     <link rel="index" title="Index" href="#" />
     <link rel="search" title="Search" href="search.html" /> 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -71,6 +68,10 @@
  <a href="#A"><strong>A</strong></a>
  | <a href="#C"><strong>C</strong></a>
  | <a href="#L"><strong>L</strong></a>
+ | <a href="#P"><strong>P</strong></a>
+ | <a href="#R"><strong>R</strong></a>
+ | <a href="#X"><strong>X</strong></a>
+ | <a href="#Y"><strong>Y</strong></a>
  
 </div>
 <h2 id="A">A</h2>
@@ -115,6 +116,38 @@
   </ul></td>
 </tr></table>
 
+<h2 id="P">P</h2>
+<table style="width: 100%" class="indextable genindextable"><tr>
+  <td style="width: 33%; vertical-align: top;"><ul>
+      <li><a href="cfelpyutils.geometry_utils.html#cfelpyutils.geometry_utils.PixelMaps">PixelMaps (class in cfelpyutils.geometry_utils)</a>
+</li>
+  </ul></td>
+</tr></table>
+
+<h2 id="R">R</h2>
+<table style="width: 100%" class="indextable genindextable"><tr>
+  <td style="width: 33%; vertical-align: top;"><ul>
+      <li><a href="cfelpyutils.geometry_utils.html#cfelpyutils.geometry_utils.PixelMaps.r">r (cfelpyutils.geometry_utils.PixelMaps attribute)</a>
+</li>
+  </ul></td>
+</tr></table>
+
+<h2 id="X">X</h2>
+<table style="width: 100%" class="indextable genindextable"><tr>
+  <td style="width: 33%; vertical-align: top;"><ul>
+      <li><a href="cfelpyutils.geometry_utils.html#cfelpyutils.geometry_utils.PixelMaps.x">x (cfelpyutils.geometry_utils.PixelMaps attribute)</a>
+</li>
+  </ul></td>
+</tr></table>
+
+<h2 id="Y">Y</h2>
+<table style="width: 100%" class="indextable genindextable"><tr>
+  <td style="width: 33%; vertical-align: top;"><ul>
+      <li><a href="cfelpyutils.geometry_utils.html#cfelpyutils.geometry_utils.PixelMaps.y">y (cfelpyutils.geometry_utils.PixelMaps attribute)</a>
+</li>
+  </ul></td>
+</tr></table>
+
 
 
           </div>
@@ -136,7 +169,7 @@
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/index.html b/doc/build/html/index.html
index 211403123ab8fe7838d4295af5ba74881ca02833..9cc33b6fc9c573d165a3bb302e7c08c2867d60d2 100644
--- a/doc/build/html/index.html
+++ b/doc/build/html/index.html
@@ -1,16 +1,13 @@
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>Welcome to cfelpyutils’s documentation! &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -27,7 +24,7 @@
     <link rel="index" title="Index" href="genindex.html" />
     <link rel="search" title="Search" href="search.html" /> 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -44,7 +41,7 @@
         <div class="sphinxsidebarwrapper">
   <h3><a href="#">Table Of Contents</a></h3>
   <ul>
-<li><a class="reference internal" href="#">Welcome to cfelpyutils&#8217;s documentation!</a></li>
+<li><a class="reference internal" href="#">Welcome to cfelpyutils’s documentation!</a></li>
 <li><a class="reference internal" href="#indices-and-tables">Indices and tables</a></li>
 </ul>
 
@@ -74,7 +71,7 @@
           <div class="body" role="main">
             
   <div class="section" id="welcome-to-cfelpyutils-s-documentation">
-<h1>Welcome to cfelpyutils&#8217;s documentation!<a class="headerlink" href="#welcome-to-cfelpyutils-s-documentation" title="Permalink to this headline">¶</a></h1>
+<h1>Welcome to cfelpyutils’s documentation!<a class="headerlink" href="#welcome-to-cfelpyutils-s-documentation" title="Permalink to this headline">¶</a></h1>
 <p>Contents:</p>
 <div class="toctree-wrapper compound">
 </div>
@@ -108,7 +105,7 @@
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/modules.html b/doc/build/html/modules.html
index 5562e7c6f844c03ea0cc0890a588ab007fe5ff92..950cef6783dafdb459d3b0940f1f790e9dc184fb 100644
--- a/doc/build/html/modules.html
+++ b/doc/build/html/modules.html
@@ -1,16 +1,13 @@
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>cfelpyutils &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -27,7 +24,7 @@
     <link rel="index" title="Index" href="genindex.html" />
     <link rel="search" title="Search" href="search.html" /> 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -105,7 +102,7 @@
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/objects.inv b/doc/build/html/objects.inv
index ec0b69617810b39692e04b3d4c1c20a3b1e6e378..3a4683af811c503ddd611e3e57561bcc002846b7 100644
Binary files a/doc/build/html/objects.inv and b/doc/build/html/objects.inv differ
diff --git a/doc/build/html/py-modindex.html b/doc/build/html/py-modindex.html
index 01f0bcc5a461134581ba714245a73d1b227937fc..07cc5eb80eefaec433ebb2ac730a3b79ba5aee0c 100644
--- a/doc/build/html/py-modindex.html
+++ b/doc/build/html/py-modindex.html
@@ -1,16 +1,13 @@
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>Python Module Index &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -30,7 +27,7 @@
 
 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -117,7 +114,7 @@
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/search.html b/doc/build/html/search.html
index 81cbbb6427346e757469fe17d1fba35834d37923..505f5ab890619f87bc4003d303f6703e22e1eae3 100644
--- a/doc/build/html/search.html
+++ b/doc/build/html/search.html
@@ -1,16 +1,13 @@
+
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
-
 <html xmlns="http://www.w3.org/1999/xhtml">
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    
     <title>Search &#8212; cfelpyutils 0.5 documentation</title>
-    
     <link rel="stylesheet" href="_static/sphinxdoc.css" type="text/css" />
     <link rel="stylesheet" href="_static/pygments.css" type="text/css" />
-    
     <script type="text/javascript">
       var DOCUMENTATION_OPTIONS = {
         URL_ROOT:    './',
@@ -35,7 +32,7 @@
    
 
   </head>
-  <body role="document">
+  <body>
     <div class="related" role="navigation" aria-label="related navigation">
       <h3>Navigation</h3>
       <ul>
@@ -101,7 +98,7 @@
     </div>
     <div class="footer" role="contentinfo">
         &#169; Copyright 2016, CFEL Team.
-      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.5.6.
+      Created using <a href="http://sphinx-doc.org/">Sphinx</a> 1.6.6.
     </div>
   </body>
 </html>
\ No newline at end of file
diff --git a/doc/build/html/searchindex.js b/doc/build/html/searchindex.js
index 98399e185796caa2074a6945eff5fd64fce0b787..bfecff634fbd2d91e9bb0e3411fd93acf7bd7dbc 100644
--- a/doc/build/html/searchindex.js
+++ b/doc/build/html/searchindex.js
@@ -1 +1 @@
-Search.setIndex({docnames:["cfelpyutils","cfelpyutils.crystfel_utils","cfelpyutils.geometry_utils","cfelpyutils.parameter_utils","index","modules"],envversion:51,filenames:["cfelpyutils.rst","cfelpyutils.crystfel_utils.rst","cfelpyutils.geometry_utils.rst","cfelpyutils.parameter_utils.rst","index.rst","modules.rst"],objects:{"":{cfelpyutils:[0,0,0,"-"]},"cfelpyutils.crystfel_utils":{load_crystfel_geometry:[1,1,1,""]},"cfelpyutils.geometry_utils":{adjust_pixel_maps_for_pyqtgraph:[2,1,1,""],apply_pixel_maps:[2,1,1,""],compute_minimum_array_size:[2,1,1,""],compute_pixel_maps:[2,1,1,""]},"cfelpyutils.parameter_utils":{convert_parameters:[3,1,1,""]},cfelpyutils:{crystfel_utils:[1,0,0,"-"],geometry_utils:[2,0,0,"-"],parameter_utils:[3,0,0,"-"]}},objnames:{"0":["py","module","Python module"],"1":["py","function","Python function"]},objtypes:{"0":"py:module","1":"py:function"},terms:{"41a8fa9819010fe8ddeb66676fee717f5226c7b8":1,"boolean":3,"class":0,"default":2,"float":3,"function":[0,1,2],"import":0,"int":2,"new":2,"return":[1,2,3],"true":3,"try":3,For:1,The:[1,2,3],accord:3,adjust:2,adjust_pixel_maps_for_pyqtgraph:2,all:[2,3],allow:0,ani:3,appli:[2,3],apply_pixel_map:2,argument:0,arrai:2,assign:3,automat:[0,2],base:0,beam:2,been:2,big:2,brace:3,bracket:3,can:2,cannot:3,center:2,cfel:0,cfelfabio:0,cfelgeom:0,cfelhdf5:0,cfeloptarg:0,cfelpsana:0,chang:3,code:1,command:[0,3],commit:1,comput:2,compute_minimum_array_s:2,compute_pixel_map:2,config:3,config_dict:3,configpars:3,configur:3,contain:[0,1,2,3],content:[3,4,5],convert:[1,3],convert_paramet:3,coordin:2,coordinateand:2,correct:3,corrent:3,correspond:3,creat:2,crystfel:[0,1,2],crystfel_geometri:1,crystfel_util:[0,2,5],curli:3,current:1,data:[1,2,3],describ:2,desi:1,detector:2,determin:3,dict:[1,2,3],dictionari:[1,2,3],displai:2,distanc:2,document:1,doubl:3,dtype:2,each:[2,3],els:3,end:3,enough:2,entri:[1,3],etc:0,except:3,expand:0,fabio:0,fail:3,fals:3,field:2,file:[0,1,3],filenam:1,fill:2,first:[2,3],float32:2,follow:[0,3],format:[0,1,2],from:[1,2],full:1,geometri:[0,1,2],geometry_util:[0,5],get_detector_geometry_2:1,h5py:0,has:2,hdf5:0,html:1,http:1,imag:0,imageview:2,index:4,inform:[1,2],input:[2,3],instead:2,integ:3,interact:2,interoper:1,interpret:3,kei:1,layout:2,leav:3,line:[0,3],list:3,load:[1,2],load_crystfel_geometri:[1,2],mani:0,manipul:2,manual:1,map:2,match:3,minimum:2,modul:[4,5],name:2,ndarrai:2,non:0,none:[2,3],nonetyp:3,number:3,numpi:2,object:[2,3],option:[2,3],order:3,origin:2,output:2,output_arrai:2,packag:[1,5],page:4,paramet:[0,1,2,3],parameter_util:[0,5],pars:[0,3],parser:3,physic:2,pixel:2,pixel_map:2,pixelmap:2,point:2,prealloc:2,previou:3,process:0,project:0,provid:[0,2],psana:0,pyqtgraph:2,python:[0,1,3],quot:3,rai:0,rais:3,read:[1,3],refer:2,reimplement:1,represent:2,respect:2,rule:3,runtimeerror:3,same:3,search:4,see:1,set:[2,3],sever:0,shape:2,should:2,singl:3,size:2,softwar:[0,1],squar:3,start:3,store:2,str:1,string:3,structur:3,style:[0,2],submodul:5,support:3,suppos:2,sync:1,system:2,take:2,thi:[0,1,2],third:2,tupl:2,turn:2,twhite:1,two:2,type:[1,2,3],used:[0,1,2],user:2,util:[0,1,2,3],valu:2,visual:2,which:[0,2],widget:2,without:3,word:3,work:0,www:1},titles:["cfelpyutils package","cfelpyutils.crystfel_utils module","cfelpyutils.geometry_utils module","cfelpyutils.parameter_utils module","Welcome to cfelpyutils&#8217;s documentation!","cfelpyutils"],titleterms:{cfelpyutil:[0,1,2,3,4,5],content:0,crystfel_util:1,document:4,geometry_util:2,indic:4,modul:[0,1,2,3],packag:0,parameter_util:3,submodul:0,tabl:4,welcom:4}})
\ No newline at end of file
+Search.setIndex({docnames:["cfelpyutils","cfelpyutils.crystfel_utils","cfelpyutils.geometry_utils","cfelpyutils.parameter_utils","index","modules"],envversion:53,filenames:["cfelpyutils.rst","cfelpyutils.crystfel_utils.rst","cfelpyutils.geometry_utils.rst","cfelpyutils.parameter_utils.rst","index.rst","modules.rst"],objects:{"":{cfelpyutils:[0,0,0,"-"]},"cfelpyutils.crystfel_utils":{load_crystfel_geometry:[1,1,1,""]},"cfelpyutils.geometry_utils":{PixelMaps:[2,2,1,""],adjust_pixel_maps_for_pyqtgraph:[2,1,1,""],apply_pixel_maps:[2,1,1,""],compute_minimum_array_size:[2,1,1,""],compute_pixel_maps:[2,1,1,""]},"cfelpyutils.geometry_utils.PixelMaps":{r:[2,3,1,""],x:[2,3,1,""],y:[2,3,1,""]},"cfelpyutils.parameter_utils":{convert_parameters:[3,1,1,""]},cfelpyutils:{crystfel_utils:[1,0,0,"-"],geometry_utils:[2,0,0,"-"],parameter_utils:[3,0,0,"-"]}},objnames:{"0":["py","module","Python module"],"1":["py","function","Python function"],"2":["py","class","Python class"],"3":["py","attribute","Python attribute"]},objtypes:{"0":"py:module","1":"py:function","2":"py:class","3":"py:attribute"},terms:{"41a8fa9819010fe8ddeb66676fee717f5226c7b8":1,"boolean":3,"class":[0,2],"default":2,"export":[1,2,3],"float":3,"function":[0,1,2,3],"import":0,"int":[2,3],"new":2,"return":[1,2,3],"true":3,"try":3,For:1,The:[1,2,3],accord:3,adjust:2,adjust_pixel_maps_for_pyqtgraph:2,ajust:2,alia:2,all:[2,3],allow:0,also:2,ani:3,appli:[2,3],apply_pixel_map:2,argument:0,arrai:2,assign:3,automat:[0,2],base:[0,2],beam:2,been:2,big:2,brace:3,bracket:3,can:2,cannot:3,center:2,cfel:0,cfelfabio:0,cfelgeom:0,cfelhdf5:0,cfeloptarg:0,cfelpsana:0,code:1,command:[0,3],commit:1,comput:2,compute_minimum_array_s:2,compute_pixel_map:2,config:3,config_dict:3,configpars:3,configur:3,contain:[0,2,3],contan:3,content:[3,4,5],convert:[1,3],convert_paramet:3,coordin:2,correct:3,creat:2,crystfel:[0,1,2],crystfel_geometri:1,crystfel_util:[0,2,5],curli:3,data:[1,2,3],dataset:2,describ:2,desi:1,detector:2,determin:3,dict:[1,2,3],dictionar:3,dictionari:[1,2,3],displai:2,distanc:2,document:1,doubl:3,dtype:2,each:[2,3],els:3,end:3,enough:2,entri:[1,3],etc:[0,3],except:3,expand:0,fabio:0,fail:3,fals:3,field:2,file:[0,1,3],filenam:1,fill:2,first:[2,3],float32:2,follow:[0,3],format:[0,1,2],from:[1,2,3],full:1,geometri:[0,1,2],geometry_util:[0,5],get_detector_geometry_2:1,h5py:0,has:2,hdf5:0,html:1,http:1,imag:0,imageview:2,index:4,inform:[1,2],input:[2,3],instead:2,integ:3,interact:2,interoper:1,interpret:3,just:2,kei:1,layout:2,leav:3,line:[0,3],list:3,load:[1,2],load_crystfel_geometri:[1,2],mani:0,manipul:2,manual:1,map:2,match:3,minimum:2,modul:[4,5],name:2,namedtupl:2,ndarrai:2,non:0,none:[2,3],nonetyp:3,number:[2,3],numpi:2,object:2,option:[2,3],order:3,origin:2,other:2,output:2,output_arrai:2,packag:[1,5],page:4,paramet:[0,1,2,3],parameter_util:[0,5],pars:[0,3],parser:3,physic:2,pixel:2,pixel_map:2,pixelmap:2,point:2,prealloc:2,previou:3,process:0,project:0,provid:[0,2],psana:0,pyqtgraph:2,python:[0,1],quot:3,rai:0,rais:3,read:1,refer:2,reimplement:1,represent:2,requir:2,respect:2,rule:3,runtimeerror:3,same:3,search:4,see:1,set:[2,3],sever:0,shape:2,singl:3,size:2,softwar:[0,1],squar:3,start:3,store:2,str:1,string:3,structur:3,style:[0,2],submodul:5,support:3,suppos:2,sync:1,system:2,take:2,thi:[0,1,2],third:2,tupl:2,turn:2,twhite:1,two:2,type:[1,2,3],used:[0,1,2],user:2,util:[0,1,2,3],valu:2,visual:2,which:[0,2],widget:2,without:3,word:[2,3],work:0,www:1},titles:["cfelpyutils package","cfelpyutils.crystfel_utils module","cfelpyutils.geometry_utils module","cfelpyutils.parameter_utils module","Welcome to cfelpyutils\u2019s documentation!","cfelpyutils"],titleterms:{cfelpyutil:[0,1,2,3,4,5],content:0,crystfel_util:1,document:4,geometry_util:2,indic:4,modul:[0,1,2,3],packag:0,parameter_util:3,submodul:0,tabl:4,welcom:4}})
\ No newline at end of file
diff --git a/geometry_utils.py b/geometry_utils.py
index 699d8223cd535cea34d711f17ad5bb2b200c7038..bb95c5f2475c5c7480b0f3e98f07e3814a3b4649 100644
--- a/geometry_utils.py
+++ b/geometry_utils.py
@@ -13,12 +13,26 @@
 #    You should have received a copy of the GNU General Public License
 #    along with cfelpyutils.  If not, see <http://www.gnu.org/licenses/>.
 """
-Geometry utilities.
-
-Functions that load, manipulate and apply geometry information to
+Utilities to load, manipulate and apply geometry information to
 detector pixel data.
-"""
 
+Exports:
+
+    Functions:
+
+        compute_pixel_maps: turn a CrystFEL geometry object into pixel
+            maps.
+
+        apply_pixel_maps: apply pixel maps to a data array. Return an
+            array containing data with the geometry applied.
+
+        compute_minimum_array_size: compute the minimum array size that
+            is required to store data to which a geometry has been
+            applied.
+
+        adjust_pixel_maps_for_pyqtgraph: ajust pixel maps to be used in
+            a PyQtGraph's ImageView widget.
+"""
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
@@ -27,6 +41,21 @@ import collections
 import numpy
 
 
+PixelMaps = collections.namedtuple(  # pylint: disable=C0103
+    typename='PixelMaps',
+    field_names=['x', 'y', 'r']
+)
+"""
+Pixel maps storing data geometry.
+
+A namedtuple that stores the pixel maps describing the geometry of a
+dataset. The first two fields, named "x" and "y" respectively, store
+the pixel maps for the x coordinate and the y coordinate. The third
+field, named "r", is instead a pixel map storing the distance of each
+pixel in the data array from the center of the reference system.
+"""
+
+
 def compute_pixel_maps(geometry):
     """
     Compute pixel maps from a CrystFEL geometry object.
@@ -46,12 +75,7 @@ def compute_pixel_maps(geometry):
 
     Returns:
 
-        Tuple[ndarray, ndarray, ndarray] A tuple containing the pixel
-        maps. The first two fields, named "x" and "y" respectively,
-        store the pixel maps for the x coordinate and the y coordinate.
-        The third field, named "r", is instead a pixel map storing the
-        distance of each pixel in the data array from the center of the
-        reference system.
+        PixelMaps: A PixelMaps tuple.
     """
     # Determine the max fs and ss in the geometry object.
     max_slab_fs = numpy.array([
@@ -68,16 +92,16 @@ def compute_pixel_maps(geometry):
     # will store the x and y pixel maps.
     x_map = numpy.zeros(
         shape=(max_slab_ss + 1, max_slab_fs + 1),
-        dtype=numpy.float32
+        dtype=numpy.float32  # pylint: disable=E1101
     )
 
     y_map = numpy.zeros(
         shape=(max_slab_ss + 1, max_slab_fs + 1),
-        dtype=numpy.float32
+        dtype=numpy.float32  # pylint: disable=E1101
     )
 
     # Iterate over the panels. For each panel, determine the pixel
-    # indeces, then compute the x,y vectors using a comples notation.
+    # indices, then compute the x,y vectors using a comples notation.
     for pan in geometry['panels']:
         i, j = numpy.meshgrid(
             numpy.arange(
@@ -120,18 +144,15 @@ def compute_pixel_maps(geometry):
     # Finally, compute the values for the radius pixel map.
     r_map = numpy.sqrt(numpy.square(x_map) + numpy.square(y_map))
 
-    PixelMaps = collections.namedtuple(
-        typename='PixelMaps',
-        field_names=['x', 'y', 'r']
-    )
     return PixelMaps(x_map, y_map, r_map)
 
 
 def apply_pixel_maps(data, pixel_maps, output_array=None):
     """
-    Apply geometry in pixel map format to the input data.
+    Apply geometry to the input data.
 
-    Turn an array of detector pixel values into an array
+    Apply the geometry (in pixel maps format) to the data. In other
+    words, turn an array of detector pixel values into an array
     containing a representation of the physical layout of the detector.
 
     Args:
@@ -139,8 +160,7 @@ def apply_pixel_maps(data, pixel_maps, output_array=None):
         data (ndarray): array containing the data on which the geometry
             will be applied.
 
-        pixel_maps (PixelMaps): a pixelmap tuple, as returned by the
-            :obj:`compute_pixel_maps` function in this module.
+        pixel_maps (PixelMaps): a PixelMaps tuple.
 
         output_array (Optional[ndarray]): a preallocated array (of
             dtype numpy.float32) to store the function output. If
@@ -151,15 +171,15 @@ def apply_pixel_maps(data, pixel_maps, output_array=None):
 
     Returns:
 
-        ndarray: a numpy.float32 array containing the geometry
-        information applied to the input data (i.e.: a representation
-        of the physical layout of the detector).
+        ndarray: a numpy.float32 array containing the data with the
+        geometry applied (i.e.: a representation of the physical layout
+        of the detector).
     """
     # If no output array was provided, create one.
     if output_array is None:
         output_array = numpy.zeros(
             shape=data.shape,
-            dtype=numpy.float32
+            dtype=numpy.float32  # pylint: disable=E1101
         )
 
     # Apply the pixel map geometry information the data, then return
@@ -170,8 +190,7 @@ def apply_pixel_maps(data, pixel_maps, output_array=None):
 
 def compute_minimum_array_size(pixel_maps):
     """
-    Compute the minimum size of an array that can store the applied
-    geometry.
+    Compute the minimum array size storing data with applied geometry.
 
     Return the minimum size of an array that can store data on which
     the geometry information described by the pixel maps has been
@@ -179,17 +198,12 @@ def compute_minimum_array_size(pixel_maps):
 
     The returned array shape is big enough to display all the input
     pixel values in the reference system of the physical detector. The
-    array is supposed to be centered at the center of the reference
-    system of the detector (i.e: the beam interaction point).
+    array is also supposed to be centered at the center of the
+    reference system of the detector (i.e: the beam interaction point).
 
     Args:
 
-        Tuple[ndarray, ndarray, ndarray]: a named tuple containing the
-            pixel maps. The first two fields, "x" and "y", should store
-            the pixel maps for the x coordinateand the y coordinate.
-            The third, "r", should instead store the distance of each
-            pixel in the data array from the center of the reference
-            system.
+        pixel_maps [PixelMaps]: a PixelMaps tuple.
 
     Returns:
 
@@ -200,7 +214,7 @@ def compute_minimum_array_size(pixel_maps):
     # the returned array is centered on the origin, the minimum array
     # size along a certain axis must be at least twice the maximum
     # value for that axis. 2 pixels are added for good measure.
-    x_map, y_map = pixel_maps.x, pixel_maps.x.y
+    x_map, y_map = pixel_maps.x, pixel_maps.y
     y_minimum = 2 * int(max(abs(y_map.max()), abs(y_map.min()))) + 2
     x_minimum = 2 * int(max(abs(x_map.max()), abs(x_map.min()))) + 2
 
@@ -217,20 +231,14 @@ def adjust_pixel_maps_for_pyqtgraph(pixel_maps):
 
     Args:
 
-        Tuple[ndarray, ndarray, ndarray]: a named tuple containing the
-        pixel maps. The first two fields, "x" and "y", should store the
-        pixel maps for the x coordinateand the y coordinate. The third,
-        "r", should instead store the distance of each pixel in the
-        data array from the center of the reference system.
+        pixel_maps (PixelMaps): a PixelMaps tuple.
 
     Returns:
 
-        Tuple[ndarray, ndarray] A tuple containing the pixel
+        PixelMaps: A Pixelmaps tuple containing the adjusted pixel
             maps. The first two fields, named "x" and "y" respectively,
             store the pixel maps for the x coordinate and the y
-            coordinate. The third field, named "r", is instead a pixel
-            map storing the distance of each pixel in the data array
-            from the center of the reference system.
+            coordinate. The third field ("r") is just set to None.
     """
     # Essentially, the origin of the reference system needs to be
     # moved from the beam position to the top-left of the image that
@@ -249,8 +257,4 @@ def adjust_pixel_maps_for_pyqtgraph(pixel_maps):
         dtype=numpy.int
     ) + min_shape[0] // 2 - 1
 
-    PixelMapsForIV = collections.namedtuple(
-        typename='PixelMapsForIV',
-        field_names=['x', 'y']
-    )
-    return PixelMapsForIV(new_x_map, new_y_map)
+    return PixelMaps(new_x_map, new_y_map, None)
diff --git a/parameter_utils.py b/parameter_utils.py
index 4a3fde67e974e14c1bdeeb734331021a91b40722..18c33be74e374d8a8c0eb6276bf995dc016453e6 100644
--- a/parameter_utils.py
+++ b/parameter_utils.py
@@ -14,6 +14,14 @@
 #    along with cfelpyutils.  If not, see <http://www.gnu.org/licenses/>.
 """
 Utilities for parsing command line options and configuration files.
+
+Exports:
+
+    Functions:
+
+        convert_parameters: convert a dictionary returned by the
+            configparse module to a dictionary containing entries with
+            the correct type.
 """
 
 from __future__ import (absolute_import, division, print_function,
@@ -33,11 +41,12 @@ def _parsing_error(section, option):
 
 
 def convert_parameters(config_dict):
     """Convert strings in parameter dictionaries to the corrent data type.
 
-    Read a parameter dictionary returned by the ConfigParser python
-    module, and convert each entry in an object of the corresponding
-    type, without changing the structure of the dictionary.
+    Convert a dictionary return by the configparse module to a
+    dictionar contaning the same parameters converted from string to
+    their correct type (int, float, string, etc.)
 
     Try to convert each entry in the dictionary according to the
     following rules. The first rule that applies to the entry
@@ -66,12 +75,12 @@ def convert_parameters(config_dict):
 
     Args:
 
-        config (dict): a dictionary containing strings (the dictionary
+        config (Dict): a dictionary containing strings (the dictionary
             returned by Config Parser).
 
     Returns:
 
-        dict: dictionary with the same structure as the input
+        Dict: dictionary with the same structure as the input
         dictionary, but with correct types assigned to each entry.
 
     Raises:
@@ -92,8 +101,8 @@ def convert_parameters(config_dict):
         # the configuration file). Get each option in turn and perform
         # all the checks. If all checks fail, call the parsing_error
         # function.
-        for option in config_dict['section'].keys():
-            recovered_option = config_dict['section']
+        for option in config_dict[section].keys():
+            recovered_option = config_dict[section][option]
             if (
                     recovered_option.startswith("'") and
                     recovered_option.endswith("'")
@@ -33,11 +41,12 @@ def _parsing_error(section, option):
 
 def convert_parameters(config_dict):
-    """Convert strings in parameter dictionaries to the corrent data type.
+    """
+    Convert strings in parameter dictionaries to the correct data type.
 